@@ -1,4 +1,4 @@
-/* XEmacs site configuration template file.  -*- C -*-
+/* XEmacs configuration file for Win32                             -*- C -*-
    Copyright (C) 1986, 1991, 1992, 1993, 1994 Free Software Foundation, Inc.
 
 This file is part of XEmacs.
@@ -23,16 +23,45 @@ Boston, MA 02111-1307, USA.  */
 /* No code in XEmacs #includes config.h twice, but some of the code
    intended to work with other packages as well (like gmalloc.c) 
    think they can include it as many times as they like.  */
-#ifndef _CONFIG_H_
-#define _CONFIG_H_
-
-/* #### This will be removed in 19.15. */
-#define LOSING_BYTECODE
+#ifndef _SRC_CONFIG_H_
+#define _SRC_CONFIG_H_
 
 #define NTHEAP_PROBE_BASE 1
+#undef LOSING_BYTECODE
 
-/* These are all defined in the top-level Makefile by configure.
-   They're here only for reference.  */
+/* Use this to add code in a structured way to FSF-maintained source
+   files so as to make it obvious where XEmacs changes are. */
+#define XEMACS 1
+
+/* Allow s&m files to differentiate OS versions without having
+   multiple files to maintain. */
+#undef OS_RELEASE
+
+/* The configuration name.  This is used as the install directory name
+   for the lib-src programs. */
+/* #undef EMACS_CONFIGURATION -- defined in xemacs.mak */
+
+/* The configuration options.  This is exported to Lisp. */
+#undef EMACS_CONFIG_OPTIONS
+
+/* The version info from xemacs.mak via version.sh. Used in #pragma ident
+   in emacs.c */
+#if 0
+#undef EMACS_MAJOR_VERSION
+#undef EMACS_MINOR_VERSION
+#undef EMACS_BETA_VERSION
+#undef EMACS_VERSION
+#undef XEMACS_CODENAME
+#endif
+
+/* Make all functions available on AIX.  See AC_AIX. */
+#undef _ALL_SOURCE
+
+/* Used to identify the XEmacs version in stack traces. */
+#undef STACK_TRACE_EYE_CATCHER
+
+/* Allow the configurer to specify (additional) package directories. */
+/* #undef PACKAGE_PATH */
 
 /* Define LISP_FLOAT_TYPE if you want XEmacs to support floating-point
    numbers. */
@@ -47,20 +76,26 @@ Boston, MA 02111-1307, USA.  */
 /* Define HAVE_TTY if you want TTY support compiled in. */
 #undef HAVE_TTY
 
-/* Define HAVE_X_WINDOWS if you want to use the X window system.  */
-#define HAVE_X_WINDOWS
+/* Compile in support for the X window system? */
+/* #undef HAVE_X_WINDOWS -- defined in xemacs.mak */
 
-/* Define HAVE_NEXTSTEP if you want to use the NeXTstep window system.  */
-#undef HAVE_NEXTSTEP
-
-/* Define HAVE_WINDOW_SYSTEM if any windowing system is available.  */
-#if defined (HAVE_X_WINDOWS) || defined (HAVE_NEXTSTEP)
-#define HAVE_WINDOW_SYSTEM
+/* Defines for building X applications */
+#ifdef HAVE_X_WINDOWS
+/* The following will be defined if xmkmf thinks they are necessary */
+#undef SVR4
+#undef SYSV
+#undef AIXV3
+#undef _POSIX_SOURCE
+#undef _BSD_SOURCE
+#undef _GNU_SOURCE
+#undef X_LOCALE
+#undef NARROWPROTO
+/* The following should always be defined, no matter what xmkmf thinks. */
+#ifndef NeedFunctionPrototypes
+#define NeedFunctionPrototypes 1
 #endif
-
-/* Define HAVE_UNIXOID_EVENT_LOOP if we use select() to wait for events.  */
-#if defined (HAVE_X_WINDOWS) || defined (HAVE_TTY)
-#define HAVE_UNIXOID_EVENT_LOOP
+#ifndef FUNCPROTO
+#define FUNCPROTO 15
 #endif
 
 /* Define this if you're using XFree386.  */
@@ -70,6 +105,37 @@ Boston, MA 02111-1307, USA.  */
 #undef THIS_IS_X11R5
 #define THIS_IS_X11R6
 
+/* Define HAVE_XPM if you have the `xpm' library and want XEmacs to use it. */
+#undef HAVE_XPM
+
+/* Define HAVE_XFACE if you have the `compface' library and want to use it.
+   This will permit X-face pixmaps in mail and news messages to display
+   quickly. */
+#undef HAVE_XFACE
+
+/* #define HAVE_IMAGEMAGICK */
+
+/* Define HAVE_XMU if you have the Xmu library.  This should always be
+   the case except on losing HPUX systems. */
+#define HAVE_XMU
+
+/* Define HAVE_XAUTH if the Xauth library is present.  This will add
+   some extra functionality to gnuserv. */
+#undef HAVE_XAUTH
+
+/* Define HAVE_XLOCALE_H if X11/Xlocale.h is present. */
+#define HAVE_XLOCALE_H
+#define HAVE_UNIXOID_EVENT_LOOP
+
+#endif /* HAVE_X_WINDOWS */
+
+/* Define HAVE_WINDOW_SYSTEM if any windowing system is available.  */
+#if defined (HAVE_X_WINDOWS) || defined (HAVE_NEXTSTEP) || defined (HAVE_MS_WINDOWS)
+#define HAVE_WINDOW_SYSTEM
+#endif
+
+
+
 /* Define USER_FULL_NAME to return a string
    that is the user's full name.
    It can assume that the variable `pw'
@@ -80,9 +146,6 @@ Boston, MA 02111-1307, USA.  */
    field contains the right thing, use pw_name,
    giving the user's login name, since that is better than nothing.  */
 #define USER_FULL_NAME pw->pw_gecos
-#if 0
-#define USER_FULL_NAME unknown
-#endif
 
 /* Define AMPERSAND_FULL_NAME if you use the convention
    that & in the full name stands for the login id.  */
@@ -103,17 +166,17 @@ Boston, MA 02111-1307, USA.  */
 
 #define HAVE_SYS_TIME_H
 #define HAVE_LOCALE_H
+#ifdef HAVE_X_WINDOWS
 #define HAVE_X11_LOCALE_H
+#endif
 #define STDC_HEADERS
 #define HAVE_LIMITS_H
 #define HAVE_GETCWD
 
 #define HAVE_LONG_FILE_NAMES
 
-#ifdef HAVE_LONG_FILE_NAMES
-#define CLASH_DETECTION
-#endif
-
+#undef HAVE_LIBKSTAT
+#undef HAVE_LIBINTL
 #undef HAVE_LIBDNET
 #undef HAVE_LIBRESOLV
 
@@ -126,7 +189,6 @@ Boston, MA 02111-1307, USA.  */
 /* Define if `struct timeval' is declared by <sys/time.h>.  */
 #define HAVE_TIMEVAL
 
-
 #undef TM_IN_SYS_TIME
 #undef HAVE_TM_ZONE
 #undef HAVE_TZNAME
@@ -144,19 +206,19 @@ Boston, MA 02111-1307, USA.  */
 #undef GETTIMEOFDAY_ONE_ARGUMENT
 #endif
 
-/* Define in keyword `inline' exists. */
-#undef HAVE_INLINE
-
-#undef HAVE_ALLOCA_H
-#undef HAVE_VFORK_H
-#undef vfork
+/* Is the timezone variable already declared in system headers? */
+#undef HAVE_TIMEZONE_DECL
 
 #undef HAVE_MMAP
 #undef HAVE_STRCOLL
+#undef HAVE_GETPGRP
+#undef GETPGRP_VOID
 
 #undef SIZEOF_SHORT
 #undef SIZEOF_INT
 #undef SIZEOF_LONG
+#undef SIZEOF_LONG_LONG
+#undef SIZEOF_VOID_P
 
 #undef HAVE_ACOSH
 #undef HAVE_ASINH
@@ -217,9 +279,6 @@ Boston, MA 02111-1307, USA.  */
 
 #undef NLIST_STRUCT
 
-#undef UNEXEC_SRC
-#undef AIX_SMT_EXP
-
 /* Define HAVE_SOCKS if you have the `socks' library and want XEmacs to
    use it.  */
 #undef HAVE_SOCKS
@@ -228,83 +287,28 @@ Boston, MA 02111-1307, USA.  */
    want XEmacs to use it.  */
 #undef HAVE_TERM
 
-/* Define HAVE_XPM if you have the `xpm' library and want XEmacs to use it. */
-#undef HAVE_XPM
-
-/* Define HAVE_XFACE if you have the `compface' library and want to use it.
-   This will permit X-face pixmaps in mail and news messages to display
-   quickly. */
-#undef HAVE_XFACE
-
-/* Define HAVE_GIF if you want XEmacs to support converting GIF
-   (Graphics Interchange Format) images. */
-#undef HAVE_GIF
-
-/* Define HAVE_JPEG if you have the JPEG library and want XEmacs to use it.
-   This is for converting JPEG images. */
-#undef HAVE_JPEG
-
-/* Define HAVE_PNG if you have the PNG library and want XEmacs to use it.
-   This is for converting PNG images. */
-#undef HAVE_PNG
-
-/* Define HAVE_PNG_GNUZ if you want to use -lgz instead of -lz for PNG. */
-#undef HAVE_PNG_GNUZ
-
-/* Define HAVE_TIFF if you have the TIFF library and want XEmacs to use it.
-   This is for converting TIFF images. */
-#undef HAVE_TIFF
-
-/* Define HAVE_XMU if you have the Xmu library.  This should always be
-   the case except on losing HPUX systems. */
-#define HAVE_XMU
-
 /* Define HAVE_DBM if you want to use the DBM libraries */
 #undef HAVE_DBM
 
-/* Define HAVE_GNU_DBM if you want to use the GNU DBM libraries;
-   if you define this, you should also define HAVE_DBM */
-#undef HAVE_GNU_DBM
-
 /* Define HAVE_BERKELEY_DB if you want to use the BerkDB libraries */
 #undef HAVE_BERKELEY_DB
-
-/* Define HAVE_LIBGDBM if you have -lgdbm (separated from HAVE_DBM
-   stuff because FreeBSD has the DBM routines in libc) */
-#undef HAVE_LIBGDBM
-
-/* Define HAVE_LIBDBM if you have -ldbm */
-#undef HAVE_LIBDBM
-
-/* Define HAVE_LIBDB if you have -ldb */
-#undef HAVE_LIBDB
+/* Full #include file path for Berkeley DB's db.h */
+#undef DB_H_PATH
 
 #if defined (HAVE_DBM) || defined (HAVE_BERKELEY_DB)
 # define HAVE_DATABASE
 #endif
 
-/* Define HAVE_XAUTH if the Xauth library is present.  This will add
-   some extra functionality to gnuserv. */
-#undef HAVE_XAUTH
-
-/* Define HAVE_XLOCALE_H if X11/Xlocale.h is present. */
-#define HAVE_XLOCALE_H
-
 /* Define HAVE_NCURSES if -lncurses is present. */
 #undef HAVE_NCURSES
-
-/* Define HAVE_NCURSES_CURSES_H if ncurses/curses.h is present. */
-#undef HAVE_NCURSES_CURSES_H
-
-/* Define HAVE_NCURSES_TERM_H if ncurses/term.h is present. */
-#undef HAVE_NCURSES_TERM_H
-
-/* Define EPOCH to include extra functionality that was present in Epoch.
-   This code has received only limited testing. */
-#undef EPOCH
+/* Full #include file paths for ncurses' curses.h and term.h. */
+#undef CURSES_H_PATH
+#undef TERM_H_PATH
 
 #define LOWTAGS
 
+#ifdef DEBUG_XEMACS
+
 /* Define USE_ASSERTIONS if you want the abort() to be changed to assert()
    If the assertion fails, assert_failed() will be called.  This is
    recommended for general use because it gives more info about the crash
@@ -312,13 +316,10 @@ Boston, MA 02111-1307, USA.  */
    or have limited core dumps out of existence. */
 #define USE_ASSERTIONS
 
-/* Define one or more of the following if you want lots of extra checks
-   (e.g. structure validation) compiled in.  These should be turned
-   on during the beta-test cycle. */
-
 /* Check the entire extent structure of a buffer each time an extent
    change is done, and do other extent-related checks. */
 #define ERROR_CHECK_EXTENTS
+
 /* Make sure that all X... macros are dereferencing the correct type,
    and that all XSET... macros (as much as possible) are setting the
    correct type of structure.  Highly recommended for all
@@ -333,9 +334,7 @@ Boston, MA 02111-1307, USA.  */
    etc. */
 #define ERROR_CHECK_MALLOC
 
-/* Define DEBUG_XEMACS if you want extra debugging code compiled in.
-   This is mainly intended for use by developers. */
-#define DEBUG_XEMACS 0
+#endif /* DEBUG_XEMACS */
 
 /* Define MEMORY_USAGE_STATS if you want extra code compiled in to
    determine where XEmacs's memory is going. */
@@ -357,22 +356,45 @@ Boston, MA 02111-1307, USA.  */
 /* Allow the user to override the default value of PURESIZE at configure
    time.  This must come before we include the sys files in order for
    it to be able to override any changes in them. */
-#undef PURESIZE
+#undef RAW_PURESIZE
 
+/* Define this if you want level 2 internationalization compliance
+   (localized collation and formatting).  Generally this should be
+   defined, unless your system doesn't have the strcoll() and
+   setlocale() library routines.  This really should be (NOT! -mrb)
+   defined in the appropriate s/ or m/ file. */
+#undef I18N2
 
-/* Define this if you want to use the Common Desktop Environment
-*/
+/* Define this if you want level 3 internationalization compliance
+   (localized messaging).  This will cause a small runtime performance
+   penalty, as the strings are read from the message catalog(s).
+   For this you need the gettext() and dgetext() library routines.
+   WARNING, this code is under construction. */
+#undef I18N3
+
+/* Compile in support for CDE (Common Desktop Environment) drag and drop?
+   Requires libDtSvc, which typically must be present at runtime.  */
 #undef HAVE_CDE
 
+/* Compile in support for OffiX Drag and Drop? */
+#undef HAVE_OFFIX_DND
+
+/* Compile in generic Drag'n'Drop API */
+#define HAVE_DRAGNDROP
+
+/* Compile in support for proper session-management. */
+#undef HAVE_SESSION
+
 /* Define this if you want Mule support (multi-byte character support).
    There may be some performance penalty, although it should be small
    if you're working with ASCII files. */
-#define MULE
+/* #undef MULE */
 
+#ifdef MULE
 /* Do we want to use X window input methods for use with Mule? (requires X11R5)
    If so, use raw Xlib or higher level Motif interface? */
-#define HAVE_XIM
-#define XIM_XLIB
+#undef HAVE_XIM
+#undef XIM_XLIB
 #undef XIM_MOTIF
 
 /* Non-XIM input methods for use with Mule. */
@@ -380,6 +402,8 @@ Boston, MA 02111-1307, USA.  */
 #undef HAVE_WNN
 #undef WNN6
 
+#endif
+
 /* enable special GNU Make features in the Makefiles. */
 #undef USE_GNU_MAKE
 
@@ -388,16 +412,7 @@ Boston, MA 02111-1307, USA.  */
    compiling-running-crashing. */
 #undef NO_DOC_FILE
 
-  /* To eliminate use of `const' in the XEmacs sources,
-     do `#define CONST_IS_LOSING' */
-#define CONST_IS_LOSING
-
-# undef CONST
-# ifdef CONST_IS_LOSING
-#  define CONST
-# else
-#  define CONST const
-# endif /* CONST */
+#define CONST const
 
 /* If not defined, use unions instead of ints.  A few systems (DEC Alpha)
    seem to require this, probably because something with the int
@@ -431,38 +446,10 @@ Boston, MA 02111-1307, USA.  */
 #define SYSTEM_MALLOC
 #endif
 
-/* The configuration name.  This is used as the install directory name
-   for the lib-src programs. */
-#undef EMACS_CONFIGURATION
-
 /* Define REL_ALLOC if you want to use the relocating allocator for
    buffer space. */
 #undef REL_ALLOC
 
-/* Define LD_SWITCH_SITE to contain any special flags your loader may need.  */
-#undef LD_SWITCH_SITE
-
-/* Define C_SWITCH_SITE to contain any special flags your compiler needs.  */
-#undef C_SWITCH_SITE
-
-/* Define LD_SWITCH_X_SITE to contain any special flags your loader
-   may need to deal with X Windows.  For instance, if you've defined
-   HAVE_X_WINDOWS above and your X libraries aren't in a place that
-   your loader can find on its own, you might want to add "-L/..." or
-   something similar.  */
-#undef LD_SWITCH_X_SITE
-
-/* Define LD_SWITCH_X_SITE_AUX with an -R option
-   in case it's needed (for Solaris, for example).  */
-#undef LD_SWITCH_X_SITE_AUX
-
-/* Define C_SWITCH_X_SITE to contain any special flags your compiler
-   may need to deal with X Windows.  For instance, if you've defined
-   HAVE_X_WINDOWS above and your X include files aren't in a place
-   that your compiler can find on its own, you might want to add
-   "-I/..." or something similar.  */
-#undef C_SWITCH_X_SITE
-
 /* Define the return type of signal handlers if the s-xxx file
    did not already do so.  */
 #define RETSIGTYPE void
@@ -473,24 +460,18 @@ Boston, MA 02111-1307, USA.  */
 #define SIGRETURN return
 #endif
 
+/* Allow the source to use standard types */
+#undef size_t
+#undef pid_t
+#undef mode_t
+#undef off_t
+#undef uid_t
+#undef gid_t
+
 /* Define DYNODUMP if it is necessary to properly dump on this system.
    Currently this is only Solaris. */
 #undef DYNODUMP
 
-/* Define NEED_XILDOFF if the -xildoff flag must be passed to cc to
-   avoid invoking the incremental linker ild which is incompatible
-   with dynodump.  This is needed for recent Sunsoft compilers. */
-#undef NEED_XILDOFF
-
-/* Define ENERGIZE to compile with support for the Energize Programming System.
-   If you do this, don't forget to define ENERGIZE in lwlib/Imakefile as well.
-   You will need to set your C_SWITCH_SITE and LD_SWITCH_SITE to point at the
-   Energize connection library (libconn.a) and associated header files.
- */
-#undef ENERGIZE
-#undef ENERGIZE_2
-#undef ENERGIZE_3
-
 /* Define SUNPRO to compiled in support for Sun Sparcworks. */
 #undef SUNPRO
 
@@ -501,7 +482,7 @@ Boston, MA 02111-1307, USA.  */
    and Solaris systems; on Solaris, you may need to install the "SUNWaudmo"
    package.)
  */
-#undef HAVE_NATIVE_SOUND
+/* #undef HAVE_NATIVE_SOUND */
 
 /* If you wish to compile with support for the Network Audio System
    system define HAVE_NAS_SOUND.
@@ -517,6 +498,8 @@ Boston, MA 02111-1307, USA.  */
 /* Define TOOLTALK if your site supports the ToolTalk library. */
 #undef TOOLTALK
 
+#ifdef HAVE_X_WINDOWS
+
 #undef LWLIB_USES_MOTIF
 #define LWLIB_MENUBARS_LUCID
 #undef LWLIB_MENUBARS_MOTIF
@@ -532,6 +515,7 @@ Boston, MA 02111-1307, USA.  */
 #define HAVE_DIALOGS
 #undef HAVE_TOOLBARS
 
+#endif
 
 #if defined (HAVE_MENUBARS) || defined (HAVE_DIALOGS)
 #define HAVE_POPUPS
@@ -559,65 +543,14 @@ Boston, MA 02111-1307, USA.  */
 circumstances; this can be used to make sure things compile OK
 on various systems. */
 #undef DEBUG_ENCAPSULATION
-#define DONT_ENCAPSULATE
 
-/* basic system calls */
+/* System calls that are encapsulated */
+#define ENCAPSULATE_RENAME
+#define ENCAPSULATE_OPEN
+#define ENCAPSULATE_FOPEN
+#define ENCAPSULATE_MKDIR
 
-#if defined (INTERRUPTIBLE_IO) || defined (DEBUG_ENCAPSULATION)
-# define ENCAPSULATE_READ
-# define ENCAPSULATE_WRITE
-#endif
-#if defined (INTERRUPTIBLE_OPEN) || defined (DEBUG_ENCAPSULATION)
-# define ENCAPSULATE_OPEN
-#endif
-#if defined (INTERRUPTIBLE_CLOSE) || defined (DEBUG_ENCAPSULATION)
-# define ENCAPSULATE_CLOSE
-#endif
-
-/* stdio calls */
-
-#if defined (INTERRUPTIBLE_IO) || defined (DEBUG_ENCAPSULATION)
-# define ENCAPSULATE_FREAD
-# define ENCAPSULATE_FWRITE
-#endif
-#if defined (INTERRUPTIBLE_OPEN) || defined (DEBUG_ENCAPSULATION)
-# define ENCAPSULATE_FOPEN
-#endif
-#if defined (INTERRUPTIBLE_CLOSE) || defined (DEBUG_ENCAPSULATION)
-# define ENCAPSULATE_FCLOSE
-#endif
-
-/* directory calls */
-
-#if defined (DEBUG_ENCAPSULATION)
-# define ENCAPSULATE_CHDIR
-# define ENCAPSULATE_MKDIR
-# define ENCAPSULATE_OPENDIR
-# define ENCAPSULATE_READDIR
-# define ENCAPSULATE_RMDIR
-#endif
-
-/* file-information calls */
-
-#if defined (DEBUG_ENCAPSULATION)
-# define ENCAPSULATE_ACCESS
-# define ENCAPSULATE_LSTAT
-# define ENCAPSULATE_READLINK
-# define ENCAPSULATE_STAT
-#endif
-
-/* file-manipulation calls */
-
-#if defined (DEBUG_ENCAPSULATION)
-# define ENCAPSULATE_CHMOD
-# define ENCAPSULATE_CREAT
-# define ENCAPSULATE_LINK
-# define ENCAPSULATE_RENAME
-# define ENCAPSULATE_SYMLINK
-# define ENCAPSULATE_UNLINK
-#endif
-
-#if (defined (MSDOS) && defined (FEPCTRL)) || (defined (WIN32) && defined (USE_IME))
+#if defined (WIN32) && defined (USE_IME)
 #define HAVE_FEP
 #endif
 
@@ -629,29 +562,34 @@ on various systems. */
 #define listen Rlisten
 #endif /* HAVE_SOCKS && !DO_NOT_SOCKSIFY */
 
-#ifndef SHORTBITS
-#define SHORTBITS (8 * SIZEOF_SHORT)
+#ifndef BITS_PER_CHAR
+#define BITS_PER_CHAR 8
 #endif
-#ifndef INTBITS
-#define INTBITS (8 * SIZEOF_INT)
-#endif
-#ifndef LONGBITS
-#define LONGBITS (8 * SIZEOF_LONG)
+#define SHORTBITS (SIZEOF_SHORT * BITS_PER_CHAR)
+#define INTBITS (SIZEOF_INT * BITS_PER_CHAR)
+#define LONGBITS (SIZEOF_LONG * BITS_PER_CHAR)
+#define LONG_LONG_BITS (SIZEOF_LONG_LONG * BITS_PER_CHAR)
+#define VOID_P_BITS (SIZEOF_VOID_P * BITS_PER_CHAR)
+
+/* MSVC version >= 2.x without /Za supports __inline */
+#if (_MSC_VER < 900) || defined(__STDC__)
+# define INLINE static
+#else
+# define INLINE __inline
 #endif
 
-#ifdef HAVE_INLINE
-# if defined (__GNUC__)
-#  if defined (DONT_EXTERN_INLINE_FUNCTIONS)
-#   define INLINE inline
-#  else
-#   define INLINE extern inline
-#  endif
-# else
-#  define INLINE static inline
-# endif
-#else
-# define INLINE static
-#endif
+/* MSVC warnings no-no crap. When adding one to this section,
+   1. Think twice
+   2. Insert textual description of the warning.
+   3. Think twice. Undo still works  */
+#if (_MSC_VER >= 800)
+
+/* 'expression' : signed/unsigned mismatch */
+#pragma warning ( disable : 4018 )
+
+#endif /* compiler understands #pragma warning*/
+
+#define enum_field(enumeration_type) unsigned int
 
 /* We want to avoid saving the signal mask if possible, because
    that necessitates a system call. */
@@ -665,4 +603,24 @@ on various systems. */
 # define JMP_BUF jmp_buf
 #endif
 
-#endif /* _CONFIG_H_ */
+/* movemail options */
+/* Should movemail use POP3 for mail access? */
+#undef MAIL_USE_POP
+/* Should movemail use kerberos for POP authentication? */
+#undef KERBEROS
+/* Should movemail use hesiod for getting POP server host? */
+#undef HESIOD
+/* Determine type of mail locking. */
+/* Play preprocessor games so that configure options override s&m files */
+#undef REAL_MAIL_USE_LOCKF
+#undef REAL_MAIL_USE_FLOCK
+#undef MAIL_USE_LOCKF
+#undef MAIL_USE_FLOCK
+#ifdef REAL_MAIL_USE_FLOCK
+#define MAIL_USE_FLOCK
+#endif
+#ifdef REAL_MAIL_USE_LOCKF
+#define MAIL_USE_LOCKF
+#endif
+
+#endif /* _SRC_CONFIG_H_ */
