@@ -76,6 +76,11 @@ struct x_device
   /* Cache of GC's for frame's on this device. */
   struct gc_cache *gc_cache;
 
+  /* Selected visual, depth and colormap for this device */
+  Visual *visual;
+  int depth;
+  Colormap device_cmap;
+
   /* Used by x_bevel_modeline in redisplay-x.c */
   Pixmap gray_pixmap;
 
@@ -179,6 +184,9 @@ struct x_device
 
 #define FRAME_X_DISPLAY(f) (DEVICE_X_DISPLAY (XDEVICE (f->device)))
 #define DEVICE_X_DISPLAY(d) 	(DEVICE_X_DATA (d)->display)
+#define DEVICE_X_VISUAL(d)	(DEVICE_X_DATA (d)->visual)
+#define DEVICE_X_DEPTH(d)	(DEVICE_X_DATA (d)->depth)
+#define DEVICE_X_COLORMAP(d) 	(DEVICE_X_DATA (d)->device_cmap)
 #define DEVICE_XT_APP_SHELL(d) 	(DEVICE_X_DATA (d)->Xt_app_shell)
 #define DEVICE_X_GC_CACHE(d) 	(DEVICE_X_DATA (d)->gc_cache)
 #define DEVICE_X_GRAY_PIXMAP(d) (DEVICE_X_DATA (d)->gray_pixmap)
@@ -230,6 +238,18 @@ struct x_device
 #define DEVICE_XATOM_CHARSET_REGISTRY(d) (DEVICE_X_DATA (d)->Xatom_CHARSET_REGISTRY)
 #define DEVICE_XATOM_CHARSET_ENCODING(d) (DEVICE_X_DATA (d)->Xatom_CHARSET_ENCODING)
 
+#define Xt_SET_VALUE(widget, resource, value) do {	\
+  Arg al;						\
+  XtSetArg (al, resource, value);			\
+  XtSetValues (widget, &al, 1);				\
+} while (0)
+
+#define Xt_GET_VALUE(widget, resource, location) do {	\
+  Arg al;						\
+  XtSetArg (al, resource, location);			\
+  XtGetValues (widget, &al, 1);				\
+} while (0)
+
 /* The maximum number of widgets that can be displayed above the text
    area at one time.  Currently no more than 3 will ever actually be
    displayed (menubar, psheet, debugger panel). */
@@ -257,18 +277,6 @@ struct x_frame
   Widget top_widgets[MAX_CONCURRENT_TOP_WIDGETS];
   int num_top_widgets;
 
-#ifdef ENERGIZE
-  /* The Energize property-sheets.  The current_* slots are the ones
-     which are actually on the frame.  The desired_ slots are the ones
-     which should be there.  Redisplay synchs these.  */
-  int *current_psheets;
-  int *desired_psheets;
-  int current_psheet_count;
-  int desired_psheet_count;
-  Lisp_Object current_psheet_buffer;
-  Lisp_Object desired_psheet_buffer;
-#endif /* ENERGIZE */
-
   /*************************** Miscellaneous **************************/
 
   /* The icon pixmaps; these are Lisp_Image_Instance objects, or Qnil. */
@@ -329,15 +337,6 @@ struct x_frame
 #define FRAME_X_TOP_WIDGETS(f)	    (FRAME_X_DATA (f)->top_widgets)
 #define FRAME_X_NUM_TOP_WIDGETS(f)  (FRAME_X_DATA (f)->num_top_widgets)
 
-#ifdef ENERGIZE
-#define FRAME_X_CURRENT_PSHEETS(f)	 (FRAME_X_DATA (f)->current_psheets)
-#define FRAME_X_DESIRED_PSHEETS(f)	 (FRAME_X_DATA (f)->desired_psheets)
-#define FRAME_X_CURRENT_PSHEET_COUNT(f)  (FRAME_X_DATA (f)->current_psheet_count)
-#define FRAME_X_DESIRED_PSHEET_COUNT(f)  (FRAME_X_DATA (f)->desired_psheet_count)
-#define FRAME_X_CURRENT_PSHEET_BUFFER(f) (FRAME_X_DATA (f)->current_psheet_buffer)
-#define FRAME_X_DESIRED_PSHEET_BUFFER(f) (FRAME_X_DATA (f)->desired_psheet_buffer)
-#endif /* ENERGIZE */
-
 #define FRAME_X_ICON_PIXMAP(f)	    (FRAME_X_DATA (f)->icon_pixmap)
 #define FRAME_X_ICON_PIXMAP_MASK(f) (FRAME_X_DATA (f)->icon_pixmap_mask)
 
@@ -386,7 +385,6 @@ struct frame *x_any_window_to_frame (struct device *d, Window);
 struct frame *x_any_widget_or_parent_to_frame (struct device *d,
 					       Widget widget);
 struct frame *decode_x_frame (Lisp_Object);
-Display *get_x_display (Lisp_Object);
 struct frame *x_window_to_frame (struct device *d, Window);
 struct device *get_device_from_display (Display *dpy);
 struct device *decode_x_device (Lisp_Object);
@@ -442,13 +440,9 @@ void x_init_modifier_mapping (struct device *d);
 #define HANDLING_X_ERROR(dpy, body)	\
      ( expect_x_error ((dpy)), (body), signal_if_x_error ((dpy), 0))
 
-Lisp_Object x_atom_to_symbol (struct device *d, Atom atom);
-Atom symbol_to_x_atom (struct device *d, Lisp_Object sym,
-		       int only_if_exists);
+void Initialize_Locale (void);
 
 #ifdef HAVE_XIM
-/* Locale */
-void Initialize_Locale (void);
 
 /* X Input Method `methods' */
 void XIM_init_device     (struct device *d);
