@@ -166,6 +166,7 @@ struct device
   unsigned int extents_changed :1;
   unsigned int faces_changed :1;
   unsigned int frame_changed :1;
+  unsigned int glyphs_changed :1;
   unsigned int icon_changed :1;
   unsigned int menubar_changed :1;
   unsigned int modeline_changed :1;
@@ -191,7 +192,7 @@ struct device
   unsigned int on_console_p :1;
   unsigned int connected_to_nas_p :1;
 
-#ifdef HAVE_UNIXOID_EVENT_LOOP
+
   /* File descriptors for input and output.  Much of the time
      (but not always) these will be the same.  For an X device,
      these both hold the file descriptor of the socket used
@@ -200,13 +201,16 @@ struct device
      is used for I/O. */
   int infd, outfd;
 
+  /* infd and outfd are moved outside HAVE_UNIXOID_EVENT_LOOP conditionals,
+     because Win32, presumably the first port which does not use select()
+     polling, DOES have handles for a console device. -- kkm */
+
+#ifdef HAVE_UNIXOID_EVENT_LOOP
   /* holds some data necessary for SIGIO control.  Perhaps this should
      be inside of device_data; but it is used for both TTY's and X
      device.  Perhaps it should be conditionalized on SIGIO; but
      this requires including syssignal.h and systty.h. */
-  int old_sigio_flag;
   int old_fcntl_owner;
-  unsigned int sigio_enabled :1;
 #endif
 };
 
@@ -218,28 +222,30 @@ DECLARE_LRECORD (device, struct device);
 #define CHECK_DEVICE(x) CHECK_RECORD (x, device)
 #define CONCHECK_DEVICE(x) CONCHECK_RECORD (x, device)
 
-#define CHECK_LIVE_DEVICE(x)						\
-  do { CHECK_DEVICE (x);						\
-       if (! DEVICEP (x)						\
-	   || ! DEVICE_LIVE_P (XDEVICE (x)))				\
-         dead_wrong_type_argument (Qdevice_live_p, (x)); } while (0)
-#define CONCHECK_LIVE_DEVICE(x)						\
-  do { CONCHECK_DEVICE (x);						\
-       if (! DEVICEP (x)						\
-	   || ! DEVICE_LIVE_P (XDEVICE (x)))				\
-         x = wrong_type_argument (Qdevice_live_p, (x)); } while (0)
+#define CHECK_LIVE_DEVICE(x) do {			\
+  CHECK_DEVICE (x);					\
+  if (! DEVICE_LIVE_P (XDEVICE (x)))			\
+    dead_wrong_type_argument (Qdevice_live_p, (x));	\
+} while (0)
+#define CONCHECK_LIVE_DEVICE(x) do {			\
+  CONCHECK_DEVICE (x);					\
+  if (! DEVICE_LIVE_P (XDEVICE (x)))			\
+    x = wrong_type_argument (Qdevice_live_p, (x));	\
+} while (0)
 
 #define DEVICE_TYPE_P(d, type)	EQ (DEVICE_TYPE (d), Q##type)
 
 #ifdef ERROR_CHECK_TYPECHECK
-MAC_DECLARE_EXTERN (struct device *, MTdevice_data)
+INLINE struct device *
+error_check_device_type (struct device *d, Lisp_Object sym);
+INLINE struct device *
+error_check_device_type (struct device *d, Lisp_Object sym)
+{
+  assert (EQ (DEVICE_TYPE (d), sym));
+  return d;
+}
 # define DEVICE_TYPE_DATA(d, type)			\
-MAC_BEGIN						\
-  MAC_DECLARE (struct device *, MTdevice_data, d)	\
-  assert (DEVICE_TYPE_P (MTdevice_data, type))		\
-  MAC_SEP						\
-  (struct type##_device *) MTdevice_data->device_data	\
-MAC_END
+  ((struct type##_device *) (error_check_device_type (d, Q##type))->device_data)
 #else
 # define DEVICE_TYPE_DATA(d, type)			\
   ((struct type##_device *) (d)->device_data)
@@ -270,6 +276,10 @@ MAC_END
 #define CHECK_X_DEVICE(z) CHECK_DEVICE_TYPE (z, x)
 #define CONCHECK_X_DEVICE(z) CONCHECK_DEVICE_TYPE (z, x)
 
+#define DEVICE_MSWINDOWS_P(dev) CONSOLE_TYPESYM_MSWINDOWS_P (DEVICE_TYPE (dev))
+#define CHECK_MSWINDOWS_DEVICE(z) CHECK_DEVICE_TYPE (z, mswindows)
+#define CONCHECK_MSWINDOWS_DEVICE(z) CONCHECK_DEVICE_TYPE (z, mswindows)
+
 #define DEVICE_TTY_P(dev) CONSOLE_TYPESYM_TTY_P (DEVICE_TYPE (dev))
 #define CHECK_TTY_DEVICE(z) CHECK_DEVICE_TYPE (z, tty)
 #define CONCHECK_TTY_DEVICE(z) CONCHECK_DEVICE_TYPE (z, tty)
@@ -280,13 +290,15 @@ MAC_END
 
 #define DEVICE_WIN_P(dev) CONSOLE_TYPESYM_WIN_P (DEVICE_TYPE (dev))
 
-extern Lisp_Object Vdefault_device;
-extern Lisp_Object Qdelete_device;
-extern Lisp_Object Qdevice_live_p;
+EXFUN (Fdevice_console, 1);
+EXFUN (Fdevice_name, 1);
+EXFUN (Fmake_device, 3);
+EXFUN (Fselected_device, 1);
 
+extern Lisp_Object Qcreate_device_hook, Qdelete_device_hook, Qgrayscale;
+extern Lisp_Object Qinit_post_tty_win, Qmono, Vdefault_x_device;
 extern Lisp_Object Vdevice_class_list;
 
-extern Lisp_Object Qcolor, Qgrayscale, Qmono;
 int valid_device_class_p (Lisp_Object class);
 
 #define DEVICE_LIVE_P(d) (!EQ (DEVICE_TYPE (d), Qdead))
@@ -309,52 +321,50 @@ int valid_device_class_p (Lisp_Object class);
 #define DEVICE_BAUD_RATE(d) ((d)->baud_rate)
 #define DEVICE_INFD(d) ((d)->infd)
 #define DEVICE_OUTFD(d) ((d)->outfd)
-#define DEVICE_OLD_SIGIO_FLAG(d) ((d)->old_sigio_flag)
 #define DEVICE_OLD_FCNTL_OWNER(d) ((d)->old_fcntl_owner)
 #define DEVICE_ON_CONSOLE_P(d) ((d)->on_console_p)
 #define DEVICE_CONNECTED_TO_NAS_P(d) ((d)->connected_to_nas_p)
 
-#define LOCK_DEVICE(d) do { (d)->locked = 1; } while (0)
-#define UNLOCK_DEVICE(d) do { (d)->locked = 0; } while (0)
+#define LOCK_DEVICE(d) ((void) ((d)->locked = 1))
+#define UNLOCK_DEVICE(d) ((void) ((d)->locked = 0))
 
 #define INVALIDATE_DEVICE_PIXEL_TO_GLYPH_CACHE(d)			\
-  (d)->pixel_to_glyph_cache.valid = 0
+  ((void) ((d)->pixel_to_glyph_cache.valid = 0))
 
 #define INVALIDATE_PIXEL_TO_GLYPH_CACHE do {				\
   Lisp_Object _devcons_, _concons_;					\
   DEVICE_LOOP_NO_BREAK (_devcons_, _concons_)				\
-    INVALIDATE_DEVICE_PIXEL_TO_GLYPH_CACHE (XDEVICE (XCONS (_devcons_)->car));\
+    INVALIDATE_DEVICE_PIXEL_TO_GLYPH_CACHE (XDEVICE (XCAR (_devcons_)));\
   } while (0)
 
-#define MARK_DEVICE_FACES_CHANGED(d) do {				\
-  faces_changed = 1;							\
-  (d)->faces_changed = 1; } while (0)
+#define MARK_DEVICE_FACES_CHANGED(d)			\
+  ((void) (faces_changed = (d)->faces_changed = 1))
 
-#define MARK_DEVICE_TOOLBARS_CHANGED(d) do {				\
-  toolbar_changed = 1;							\
-  (d)->toolbar_changed = 1; } while (0)
+#define MARK_DEVICE_GLYPHS_CHANGED(d)			\
+  ((void) (glyphs_changed = (d)->glyphs_changed = 1))
 
-#define MARK_DEVICE_SIZE_CHANGED(d) do {				\
-  size_changed = 1;							\
-  (d)->size_changed = 1; } while (0)
+#define MARK_DEVICE_TOOLBARS_CHANGED(d)			\
+  ((void) (toolbar_changed = (d)->toolbar_changed = 1))
 
-#define MARK_DEVICE_FRAMES_FACES_CHANGED(d) do {			\
-  Lisp_Object frmcons;							\
-  DEVICE_FRAME_LOOP (frmcons, d)					\
-    XFRAME (XCONS (frmcons)->car)->faces_changed = 1;			\
-  MARK_DEVICE_FACES_CHANGED (d); } while (0)
+#define MARK_DEVICE_SIZE_CHANGED(d)			\
+  ((void) (size_changed = (d)->size_changed = 1))
 
-#define MARK_DEVICE_FRAME_CHANGED(d) do {				\
-  frame_changed = 1;							\
-  (d)->frame_changed = 1; } while (0)
+#define MARK_DEVICE_FRAMES_FACES_CHANGED(d) do {	\
+  struct device *mdffc_d = (d);				\
+  Lisp_Object frmcons;					\
+  DEVICE_FRAME_LOOP (frmcons, mdffc_d)			\
+    XFRAME (XCAR (frmcons))->faces_changed = 1;		\
+  MARK_DEVICE_FACES_CHANGED (mdffc_d);			\
+} while (0)
 
-#define MARK_DEVICE_WINDOWS_CHANGED(d) do {				\
-  windows_changed = 1;							\
-  (d)->windows_changed = 1; } while (0)
+#define MARK_DEVICE_FRAME_CHANGED(d)			\
+  ((void) (frame_changed = (d)->frame_changed = 1))
 
-#define MARK_DEVICE_WINDOWS_STRUCTURE_CHANGED(d) do {			\
-  windows_structure_changed = 1;					\
-  (d)->windows_structure_changed = 1; } while (0)
+#define MARK_DEVICE_WINDOWS_CHANGED(d)			\
+  ((void) (windows_changed = (d)->windows_changed = 1))
+
+#define MARK_DEVICE_WINDOWS_STRUCTURE_CHANGED(d)	\
+  ((void) (windows_structure_changed = (d)->windows_structure_changed = 1))
 
 /* This turns out to be used heavily so we make it a macro to make it
    inline.  Also, the majority of the time the object will turn out to
@@ -379,7 +389,6 @@ int valid_device_class_p (Lisp_Object class);
 
 void select_device_1 (Lisp_Object);
 struct device *decode_device (Lisp_Object);
-Lisp_Object make_device (struct device *d);
 void handle_asynch_device_change (void);
 void call_critical_lisp_code (struct device *d, Lisp_Object function,
 			      Lisp_Object object);
@@ -389,5 +398,7 @@ void delete_device_internal (struct device *d, int force,
 void io_error_delete_device (Lisp_Object device);
 Lisp_Object find_nonminibuffer_frame_not_on_device (Lisp_Object device);
 void set_device_selected_frame (struct device *d, Lisp_Object frame);
+Lisp_Object domain_device_type (Lisp_Object domain);
+int window_system_pixelated_geometry (Lisp_Object domain);
 
 #endif /* _XEMACS_DEVICE_H_ */
