@@ -36,7 +36,7 @@ Boston, MA 02111-1307, USA.  */
 #include "device.h"
 #include "insdel.h"
 
-int handle_nonfull_spec_fonts;
+int x_handle_non_fully_specified_fonts;
 
 
 /************************************************************************/
@@ -44,67 +44,163 @@ int handle_nonfull_spec_fonts;
 /************************************************************************/
 
 /* Replacement for XAllocColor() that tries to return the nearest
-   available color if the colormap is full.  From FSF Emacs. */
+   available color if the colormap is full.  Original was from FSFmacs,
+   but rewritten by Jareth Hein <jareth@camelot-soft.com> 97/11/25 */
 
+/* Return value is 1 for normal success, 2 for nearest color success,
+   3 for Non-deallocable sucess, and 0 for absolute failure (shouldn't
+   happen?) */
 int
-allocate_nearest_color (Display *display, Colormap screen_colormap,
+allocate_nearest_color (Display *display, Colormap colormap, Visual *visual,
 		        XColor *color_def)
 {
   int status;
 
-  status = XAllocColor (display, screen_colormap, color_def);
-  if (!status)
+  if (visual->class == DirectColor || visual->class == TrueColor)
     {
-      /* If we got to this point, the colormap is full, so we're
-	 going to try and get the next closest color.
-	 The algorithm used is a least-squares matching, which is
-	 what X uses for closest color matching with StaticColor visuals.  */
-
-      XColor *cells;
-      int no_cells;
-      int nearest;
-      long nearest_delta, trial_delta;
-      int x;
-
-      no_cells = XDisplayCells (display, XDefaultScreen (display));
-      cells = alloca_array (XColor, no_cells);
-
-      for (x = 0; x < no_cells; x++)
-	cells[x].pixel = x;
-
-      XQueryColors (display, screen_colormap, cells, no_cells);
-      nearest = 0;
-      /* I'm assuming CSE so I'm not going to condense this. */
-      nearest_delta = ((((color_def->red >> 8) - (cells[0].red >> 8))
-			* ((color_def->red >> 8) - (cells[0].red >> 8)))
-		       +
-		       (((color_def->green >> 8) - (cells[0].green >> 8))
-			* ((color_def->green >> 8) - (cells[0].green >> 8)))
-		       +
-		       (((color_def->blue >> 8) - (cells[0].blue >> 8))
-			* ((color_def->blue >> 8) - (cells[0].blue >> 8))));
-      for (x = 1; x < no_cells; x++)
+      if (XAllocColor (display, colormap, color_def) != 0)
 	{
-	  trial_delta = ((((color_def->red >> 8) - (cells[x].red >> 8))
-			  * ((color_def->red >> 8) - (cells[x].red >> 8)))
-			 +
-			 (((color_def->green >> 8) - (cells[x].green >> 8))
-			  * ((color_def->green >> 8) - (cells[x].green >> 8)))
-			 +
-			 (((color_def->blue >> 8) - (cells[x].blue >> 8))
-			  * ((color_def->blue >> 8) - (cells[x].blue >> 8))));
-	  if (trial_delta < nearest_delta)
-	    {
-	      nearest = x;
-	      nearest_delta = trial_delta;
+	  status = 1;
+	}
+      else
+	{
+	  /* We're dealing with a TrueColor/DirectColor visual, so play games
+	     with the RGB values in the XColor struct. */
+	  /* ### JH: I'm not sure how a call to XAllocColor can fail in a
+	     TrueColor or DirectColor visual, so I will just reformat the
+	     request to match the requirements of the visual, and re-issue
+	     the request.  If this fails for anybody, I wanna know about it
+	     so I can come up with a better plan */
+
+	  unsigned long rshift,gshift,bshift,rbits,gbits,bbits,junk;
+	  junk = visual->red_mask;
+	  rshift = 0;
+	  while ((junk & 0x1) == 0) {
+	    junk = junk >> 1;
+	    rshift ++;
+	  }
+	  rbits = 0;
+	  while (junk != 0) {
+	    junk = junk >> 1;
+	    rbits++;
+	  }
+	  junk = visual->green_mask;
+	  gshift = 0;
+	  while ((junk & 0x1) == 0) {
+	    junk = junk >> 1;
+	    gshift ++;
+	  }
+	  gbits = 0;
+	  while (junk != 0) {
+	    junk = junk >> 1;
+	    gbits++;
+	  }
+	  junk = visual->blue_mask;
+	  bshift = 0;
+	  while ((junk & 0x1) == 0) {
+	    junk = junk >> 1;
+	    bshift ++;
+	  }
+	  bbits = 0;
+	  while (junk != 0) {
+	    junk = junk >> 1;
+	    bbits++;
+ 	  }
+
+	  color_def->red = color_def->red >> (16 - rbits);
+	  color_def->green = color_def->green >> (16 - gbits);
+	  color_def->blue = color_def->blue >> (16 - bbits);
+	  if (XAllocColor (display, colormap, color_def) != 0)
+	    status = 1;
+	  else
+  	    {
+  	      int rd, gr, bl;	
+	      /* ### JH: I'm punting here, knowing that doing this will at
+		 least draw the color correctly.  However, unless we convert
+		 all of the functions that allocate colors (graphics
+		 libraries, etc) to use this function doing this is very
+		 likely to cause problems later... */
+
+	      if (rbits > 8)
+		rd = color_def->red << (rbits - 8);
+	      else
+		rd = color_def->red >> (8 - rbits);
+	      if (gbits > 8)
+		gr = color_def->green << (gbits - 8);
+	      else
+		gr = color_def->green >> (8 - gbits);
+	      if (bbits > 8)
+		bl = color_def->blue << (bbits - 8);
+	      else
+		bl = color_def->blue >> (8 - bbits);
+	      color_def->pixel = (rd << rshift) | (gr << gshift) | (bl << bshift);
+	      status = 3;
 	    }
 	}
-      color_def->red = cells[nearest].red;
-      color_def->green = cells[nearest].green;
-      color_def->blue = cells[nearest].blue;
-      status = XAllocColor (display, screen_colormap, color_def);
     }
+  else
+    {
+      if (XAllocColor (display, colormap, color_def) != 0)
+	status = 1;
+      else
+	{
+	  /* If we got to this point, the colormap is full, so we're
+	     going to try and get the next closest color.  The algorithm used
+	     is a least-squares matching, which is what X uses for closest
+	     color matching with StaticColor visuals. */
+	  XColor *cells;
+	  /* JH: I can't believe there's no way to go backwards from a
+	     colormap ID and get its visual and number of entries, but X
+	     apparently isn't built that way... */
+	  int no_cells = visual->map_entries;
+	  int nearest;
+	  long nearest_delta, trial_delta;
+	  int x;
 
+	  cells = alloca_array (XColor, no_cells);
+
+	  for (x = 0; x < no_cells; x++)
+	    cells[x].pixel = x;
+
+	  /* read the current colormap */
+	  XQueryColors (display, colormap, cells, no_cells);
+	  nearest = 0;
+	  /* I'm assuming CSE so I'm not going to condense this. */
+	  nearest_delta = ((((color_def->red >> 8) - (cells[0].red >> 8))
+			    * ((color_def->red >> 8) - (cells[0].red >> 8)))
+			   +
+			   (((color_def->green >> 8) - (cells[0].green >> 8))
+			    * ((color_def->green >> 8) - (cells[0].green >> 8)))
+			   +
+			   (((color_def->blue >> 8) - (cells[0].blue >> 8))
+			    * ((color_def->blue >> 8) - (cells[0].blue >> 8))));
+	  for (x = 1; x < no_cells; x++)
+	    {
+	      trial_delta = ((((color_def->red >> 8) - (cells[x].red >> 8))
+			      * ((color_def->red >> 8) - (cells[x].red >> 8)))
+			     +
+			     (((color_def->green >> 8) - (cells[x].green >> 8))
+			      * ((color_def->green >> 8) - (cells[x].green >> 8)))
+			     +
+			     (((color_def->blue >> 8) - (cells[x].blue >> 8))
+			      * ((color_def->blue >> 8) - (cells[x].blue >> 8))));
+	      if (trial_delta < nearest_delta)
+		{
+		  nearest = x;
+		  nearest_delta = trial_delta;
+		}
+	    }
+	  color_def->red = cells[nearest].red;
+	  color_def->green = cells[nearest].green;
+	  color_def->blue = cells[nearest].blue;
+	  if (XAllocColor (display, colormap, color_def) != 0) {
+	    status = 2;
+	  } else {
+	    status = 0; /* JH: how does this happen??? DOES this happen??? */
+	    fprintf(stderr,"allocate_nearest_color returned 0!!!\n");
+	  }
+	}
+    }
   return status;
 }
 
@@ -115,13 +211,15 @@ x_parse_nearest_color (struct device *d, XColor *color, Bufbyte *name,
   Display *dpy;
   Screen *xs;
   Colormap cmap;
+  Visual *visual;
   int result;
 
   dpy = DEVICE_X_DISPLAY (d);
   xs = DefaultScreenOfDisplay (dpy);
-  cmap = DefaultColormapOfScreen (xs);
+  cmap = DEVICE_X_COLORMAP(d);
+  visual = DEVICE_X_VISUAL (d);
 
-  memset (color, 0, sizeof (*color));
+  xzero (*color);
   {
     CONST Extbyte *extname;
     Extcount extnamelen;
@@ -135,7 +233,7 @@ x_parse_nearest_color (struct device *d, XColor *color, Bufbyte *name,
 				 Qcolor, errb);
       return 0;
     }
-  result = allocate_nearest_color (dpy, cmap, color);
+  result = allocate_nearest_color (dpy, cmap, visual, color);
   if (!result)
     {
       maybe_signal_simple_error ("couldn't allocate color",
@@ -143,7 +241,7 @@ x_parse_nearest_color (struct device *d, XColor *color, Bufbyte *name,
       return 0;
     }
 
-  return 1;
+  return result;
 }
 
 static int
@@ -164,6 +262,10 @@ x_initialize_color_instance (struct Lisp_Color_Instance *c, Lisp_Object name,
   /* Don't allocate the data until we're sure that we will succeed,
      or the finalize method may get fucked. */
   c->data = xnew (struct x_color_instance_data);
+  if (result == 3)
+    COLOR_INSTANCE_X_DEALLOC (c) = 0;
+  else
+    COLOR_INSTANCE_X_DEALLOC (c) = 1;
   COLOR_INSTANCE_X_COLOR (c) = color;
   return 1;
 }
@@ -187,11 +289,11 @@ x_finalize_color_instance (struct Lisp_Color_Instance *c)
     {
       if (DEVICE_LIVE_P (XDEVICE (c->device)))
 	{
-	  Display *dpy = DEVICE_X_DISPLAY (XDEVICE (c->device));
-
-	  XFreeColors (dpy,
-		       DefaultColormapOfScreen (DefaultScreenOfDisplay (dpy)),
-		       &COLOR_INSTANCE_X_COLOR (c).pixel, 1, 0);
+	  if (COLOR_INSTANCE_X_DEALLOC (c))
+	    {
+	      XFreeColors (DEVICE_X_DISPLAY (XDEVICE (c->device)), DEVICE_X_COLORMAP (XDEVICE (c->device)),
+			   &COLOR_INSTANCE_X_COLOR (c).pixel, 1, 0);
+	    }
 	}
       xfree (c->data);
       c->data = 0;
@@ -200,8 +302,8 @@ x_finalize_color_instance (struct Lisp_Color_Instance *c)
 
 /* Color instances are equal if they resolve to the same color on the
    screen (have the same RGB values).  I imagine that
-   "same RGV values" == "same cell in the colormap."  Arguably we should
-   be comparing their names instead. */
+   "same RGB values" == "same cell in the colormap."  Arguably we should
+   be comparing their names or pixel values instead. */
 
 static int
 x_color_instance_equal (struct Lisp_Color_Instance *c1,
@@ -236,12 +338,13 @@ x_valid_color_name_p (struct device *d, Lisp_Object color)
 {
   XColor c;
   Display *dpy = DEVICE_X_DISPLAY (d);
+  Colormap cmap = DEVICE_X_COLORMAP (d);
+
   CONST char *extname;
 
   GET_C_STRING_CTEXT_DATA_ALLOCA (color, extname);
 
-  return XParseColor (dpy,
-		      DefaultColormapOfScreen (DefaultScreenOfDisplay (dpy)),
+  return XParseColor (dpy, cmap,
 		      extname, &c);
 }
 
@@ -289,7 +392,7 @@ x_initialize_font_instance (struct Lisp_Font_Instance *f, Lisp_Object name,
   {
     /* following change suggested by Ted Phelps <phelps@dstc.edu.au> */
     unsigned int def_char = 'n'; /*xf->default_char;*/
-    int byte1, byte2;
+    unsigned int byte1, byte2;
 
   once_more:
     byte1 = def_char >> 8;
@@ -299,8 +402,10 @@ x_initialize_font_instance (struct Lisp_Font_Instance *f, Lisp_Object name,
       {
 	/* Old versions of the R5 font server have garbage (>63k) as
 	   def_char. 'n' might not be a valid character. */
-	if (byte1 < xf->min_byte1 || byte1 > xf->max_byte1 ||
-	    byte2 < xf->min_char_or_byte2 || byte2 > xf->max_char_or_byte2)
+	if (byte1 < xf->min_byte1         ||
+	    byte1 > xf->max_byte1         ||
+	    byte2 < xf->min_char_or_byte2 ||
+	    byte2 > xf->max_char_or_byte2)
 	  f->width = 0;
 	else
 	  f->width = xf->per_char[(byte1 - xf->min_byte1) *
@@ -337,7 +442,7 @@ x_initialize_font_instance (struct Lisp_Font_Instance *f, Lisp_Object name,
      defined that we could almost just get rid of this damn flag and
      make it an assertion. */
   f->proportional_p = (xf->min_bounds.width != xf->max_bounds.width ||
-		       (handle_nonfull_spec_fonts &&
+		       (x_handle_non_fully_specified_fonts &&
 			!xf->all_chars_exist));
 
   return 1;
@@ -675,7 +780,7 @@ x_font_instance_truename (struct Lisp_Font_Instance *f, Error_behavior errb)
       }
       if (NILP (FONT_INSTANCE_X_TRUENAME (f)))
 	{
-	  Lisp_Object font_instance = Qnil;
+	  Lisp_Object font_instance;
 	  XSETFONT_INSTANCE (font_instance, f);
 
 	  maybe_signal_simple_error ("couldn't determine font truename",
@@ -814,8 +919,7 @@ x_font_spec_matches_charset (struct device *d, Lisp_Object charset,
 /* find a font spec that matches font spec FONT and also matches
    (the registry of) CHARSET. */
 static Lisp_Object
-x_find_charset_font (Lisp_Object device, Lisp_Object font,
-		     Lisp_Object charset)
+x_find_charset_font (Lisp_Object device, Lisp_Object font, Lisp_Object charset)
 {
   char **names;
   int count = 0;
@@ -827,16 +931,16 @@ x_find_charset_font (Lisp_Object device, Lisp_Object font,
 
   names = XListFonts (DEVICE_X_DISPLAY (XDEVICE (device)),
 		      patternext, MAX_FONT_COUNT, &count);
+  /* ### This code seems awfully bogus -- mrb */
   for (i = 0; i < count; i ++)
     {
-      CONST char *intname;
+      CONST Bufbyte *intname;
 
       GET_C_CHARPTR_INT_BINARY_DATA_ALLOCA (names[i], intname);
       if (x_font_spec_matches_charset (XDEVICE (device), charset,
-				       (unsigned char *) intname,
-				       Qnil, 0, -1))
+				       intname, Qnil, 0, -1))
 	{
-	  result = build_string (intname);
+	  result = build_string ((char *) intname);
 	  break;
 	}
     }
@@ -894,7 +998,8 @@ console_type_create_objects_x (void)
 void
 vars_of_objects_x (void)
 {
-  DEFVAR_BOOL ("x-handle-non-fully-specified-fonts",&handle_nonfull_spec_fonts /*
+  DEFVAR_BOOL ("x-handle-non-fully-specified-fonts",
+	       &x_handle_non_fully_specified_fonts /*
 If this is true then fonts which do not have all characters specified
 will be considered to be proportional width even if they are actually
 fixed-width.  If this is not done then characters which are supposed to
@@ -905,7 +1010,7 @@ circumstances, it also causes a noticeable performance hit when using
 fixed-width fonts.  Since most people don't use characters which could
 cause problems this is set to nil by default.
 */ );
-  handle_nonfull_spec_fonts = 0;
+  x_handle_non_fully_specified_fonts = 0;
 }
 
 void
