@@ -28,10 +28,17 @@ Boston, MA 02111-1307, USA.  */
 #define DOS_NT 	/* MSDOS or WINDOWSNT */
 #endif
 
+/* In case non-Microsoft compiler is used, we fake _MSC_VER */
+#ifndef _MSC_VER
+#define _MSC_VER  1
+#endif
+
 typedef unsigned short mode_t;
-typedef long ptrdiff_t;
+/* typedef long ptrdiff_t; -kkm */
 typedef int pid_t;
 
+#include <stddef.h>
+
 /* If you are compiling with a non-C calling convention but need to
    declare vararg routines differently, put it here */
 #define _VARARGS_ __cdecl
@@ -48,9 +55,11 @@ typedef int pid_t;
 
 #define NO_MATHERR
 
-#define SIZEOF_LONG 4
+#define SIZEOF_SHORT 2
 #define SIZEOF_INT 4
-#define SIZEOF_SHORT 4
+#define SIZEOF_LONG 4
+#define SIZEOF_LONG_LONG 8
+#define SIZEOF_VOID_P 4
 
 /* NOMULTIPLEJOBS should be defined if your system's shell
  does not have "job control" (the ability to stop a program,
@@ -113,10 +122,8 @@ typedef int pid_t;
    your system and must be used only through an encapsulation
    (Which you should place, by convention, in sysdep.c).  */
 
-#if 0
-/* Define this to be the separator between path elements */
-#define DIRECTORY_SEP XINT (Vdirectory_sep_char)
-#endif
+/* XEmacs file I/O for DOS text files requires FILE_CODING */
+#define FILE_CODING
 
 #define DIRECTORY_SEP '\\'
 
@@ -150,8 +157,6 @@ typedef int pid_t;
 #define HAVE_MKDIR
 #define HAVE_RMDIR
 #define HAVE_RANDOM
-#define HAVE_BCOPY
-#define HAVE_BCMP
 #define HAVE_LOGB
 #define HAVE_FREXP
 #define HAVE_FMOD
@@ -160,12 +165,21 @@ typedef int pid_t;
 
 #define HAVE_MOUSE
 #define HAVE_H_ERRNO
+#define HAVE_STRUCT_UTIMBUF
 
 #ifdef HAVE_NTGUI
 #define HAVE_WINDOW_SYSTEM
 #define HAVE_FACES
 #endif
 
+#define HAVE_STRCASECMP
+
+/* Compatibility macros. Some used to be routines in nt.c */
+#define strcasecmp(x,y) _stricmp(x,y)
+#define random() (rand() << 15 | rand())
+#define srandom(seed) (srand(seed))
+#define setpgrp(pid,gid)
+
 #define MODE_LINE_BINARY_TEXT(_b_) (NILP ((_b_)->buffer_file_type) ? "T" : "B")
 
 /* get some redefinitions in place */
@@ -209,23 +223,35 @@ typedef int pid_t;
 #endif
 #endif
 
+#include <stdio.h>
+
 
 /* IO calls that are emulated or shadowed */
 #define pipe    sys_pipe
+int sys_pipe (int * phandles);
 
 #ifndef HAVE_X_WINDOWS
 #define sleep   sys_sleep
+void sleep (int seconds);
 #endif
 
 /* subprocess calls that are emulated */
 #define spawnve sys_spawnve
-#define wait    sys_wait
-#define kill    sys_kill
-#define signal  sys_signal
+int spawnve (int mode, CONST char *cmdname, 
+	     CONST char * CONST *argv, CONST char *CONST *envp);
 
-#define select  sys_select
+#define wait    sys_wait
+int wait (int *status);
+
+#define kill    sys_kill
+int kill (int pid, int sig);
 
 /* map to MSVC names */
+#define popen     _popen
+#define pclose    _pclose
+
+#if 0
+#define chdir     _chdir
 #define execlp    _execlp
 #define execvp    _execvp
 #define fcloseall _fcloseall
@@ -240,11 +266,9 @@ typedef int pid_t;
 #define logb      _logb
 #define _longjmp  longjmp
 #define lseek     _lseek
-#define popen     _popen
-#define pclose    _pclose
 #define putw      _putw
 #define umask     _umask
-#define utime     _utime
+/* #define utime     _utime */
 #define index     strchr
 #define rindex    strrchr
 #define read	  _read
@@ -255,26 +279,61 @@ typedef int pid_t;
 #define abort	win32_abort
 #endif
 
+#endif /* 0 */
+
+/* Encapsulation of system calls */
+#ifndef DONT_ENCAPSULATE
+#define getpid sys_getpid
+int getpid (void);
+#endif
+
+/* Random global functions called everywhere. Implemented in nt.c */
+/* #### Most of these are FSFisms and must be avoided */
+/* #### All of these are FSFisms and must be avoided */
+void dostounix_filename (char *p);
+void unixtodos_filename (char *p);
+int crlf_to_lf (int n, unsigned char *buf, unsigned int *lf_count);
+
+char *getwd (char *dir);
+
+void *sbrk (unsigned long increment);
+
+struct passwd;
+struct passwd *getpwuid (int uid);
+struct passwd *getpwnam (const char *name);
+int getuid ();
+int geteuid ();
+int getgid (void);
+int getegid ();
+
+/* Setitimer is emulated */
+#define HAVE_SETITIMER
+
+/* We now have emulation for some signals */
+#define HAVE_SIGHOLD
+#define sigset(s,h) msw_sigset(s,h)
+#define sighold(s) msw_sighold(s)
+#define sigrelse(s) msw_sigrelse(s)
+#define sigpause(s) msw_sigpause(s)
+#define signal sigset
+
 /* Defines that we need that aren't in the standard signal.h  */
 #define SIGHUP  1               /* Hang up */
 #define SIGQUIT 3               /* Quit process */
-#define SIGTRAP 5               /* Trace trap */
 #define SIGKILL 9               /* Die, die die */
-#define SIGPIPE 13              /* Write on pipe with no readers */
 #define SIGALRM 14              /* Alarm */
-#define SIGCHLD 18              /* Death of child */
+#define SIGPROF 29		/* Profiling timer exp */
 
 /* For integration with MSDOS support.  */
 #define getdisk()               (_getdrive () - 1)
 #define getdefdir(_drv, _buf)   _getdcwd (_drv, _buf, MAXPATHLEN)
 
-#define EMACS_CONFIGURATION 	get_emacs_configuration ()
-#define EMACS_CONFIG_OPTIONS	"NT"	/* Not very meaningful yet.  */
-
+#if 0 /* they do. -kkm */
 /* Define this so that winsock.h definitions don't get included when windows.h
    is...  I don't know if they do the right thing for emacs.  For this to
    have proper effect, config.h must always be included before windows.h.  */
 #define _WINSOCKAPI_    1
+#endif /* 0 */
 
 /* Defines size_t and alloca ().  */
 #include <malloc.h>
@@ -295,15 +354,19 @@ typedef int pid_t;
 #include <stdlib.h>
 #include <string.h>
 
-#if 0
-/* Emacs takes care of ensuring that these are defined.  */
-#ifdef max
-#undef max
-#undef min
-#endif
-#endif
+/* Define process implementation */
+#define HAVE_WIN32_PROCESSES
 
 /* We need a little extra space, see ../../lisp/loadup.el */
 #define SYSTEM_PURESIZE_EXTRA 15000
 
 /* ============================================================ */
+
+/* See unexnt.c */
+#if (_MSC_VER >= 1100)
+#define DUMP_SEPARATE_SECTION
+#endif
+#ifdef DUMP_SEPARATE_SECTION
+#pragma data_seg("xdata")
+#pragma bss_seg("xdata")
+#endif
