@@ -33,6 +33,7 @@ Boston, MA 02111-1307, USA.  */
 #if !defined (NO_SUBPROCESSES)
 
 #ifdef HAVE_SOCKETS	/* TCP connection support, if kernel can do it */
+# include <sys/types.h>  /* AJK */
 # include <sys/socket.h>
 # include <netdb.h>
 # include <netinet/in.h>
@@ -44,11 +45,6 @@ Boston, MA 02111-1307, USA.  */
 # include <sys/socket.h>
 #endif /* HAVE_SOCKETS */
 
-/* TERM is a poor-man's SLIP, used on Linux.  */
-#ifdef HAVE_TERM
-# include <client.h>
-#endif
-
 /* On some systems, e.g. DGUX, inet_addr returns a 'struct in_addr'. */
 #ifdef HAVE_BROKEN_INET_ADDR
 # define IN_ADDR struct in_addr
@@ -63,11 +59,7 @@ Boston, MA 02111-1307, USA.  */
 #endif
 
 /* Define first descriptor number available for subprocesses.  */
-#ifdef VMS
-# define FIRST_PROC_DESC 1
-#else /* Not VMS */
-# define FIRST_PROC_DESC 3
-#endif
+#define FIRST_PROC_DESC 3
 
 #ifdef IRIS
 # include <sys/sysmacros.h>	/* for "minor" */
@@ -105,17 +97,11 @@ Boston, MA 02111-1307, USA.  */
 #endif /* no FD_SET */
 
 #ifdef EMACS_BTL
-extern int cadillac_stop_logging ();
-extern int cadillac_start_logging ();
+int cadillac_stop_logging ();
+int cadillac_start_logging ();
 #endif
 
-#ifdef ENERGIZE
-extern Lisp_Object energize_get_buffer_process (Lisp_Object);
-extern Lisp_Object Fenergize_user_input_buffer_mark (Lisp_Object);
-extern Lisp_Object Venergize_process;
-#endif
-
-extern int poll_fds_for_input (SELECT_TYPE mask);
+int poll_fds_for_input (SELECT_TYPE mask);
 
 #ifdef MSDOS
 /* #include <process.h> */
