@@ -126,6 +126,8 @@ struct window
   Lisp_Object sb_point;
   /* Number of columns display within the window is scrolled to the left. */
   int hscroll;
+  /* Idem for the window's modeline */
+  int modeline_hscroll;
   /* Number saying how recently window was selected */
   Lisp_Object use_time;
   /* text.modified of displayed buffer as of last time display completed */
@@ -162,14 +164,6 @@ struct window
   /* need one for each set of display structures */
   int window_end_pos[3];
 
-  /* Non-nil means window is marked as dedicated.  */
-  Lisp_Object dedicated;
-
-#if 0 /* FSFmacs */
-  /* The column number currently displayed in this window's mode line,
-     or nil if column numbers are not being displayed.  */
-  Lisp_Object column_number_displayed;
-#endif
   /* If redisplay in this window goes beyond this buffer position,
      must run the redisplay-end-trigger-functions.  */
   Lisp_Object redisplay_end_trigger;
@@ -178,48 +172,9 @@ struct window
      to implement the redisplay-end-trigger-functions. */
   Bufpos last_redisplay_pos;
 
-  /* specifier values cached in the struct window: */
-
-  /* Display-table to use for displaying chars in this window. */
-  Lisp_Object display_table;
-  /* Thickness of modeline shadow, in pixels.  If negative, draw
-     as recessed. */
-  Lisp_Object modeline_shadow_thickness;
-  /* Non-nil means to display a modeline for the buffer. */
-  Lisp_Object has_modeline_p;
-#ifdef HAVE_SCROLLBARS
-  /* Width of vertical scrollbars. */
-  Lisp_Object scrollbar_width;
-  /* Height of horizontal scrollbars. */
-  Lisp_Object scrollbar_height;
-  /* Pointer to use for vertical and horizontal scrollbars. */
-  Lisp_Object scrollbar_pointer;
-#endif /* HAVE_SCROLLBARS */
-#ifdef HAVE_TOOLBARS
-  /* Toolbar specification for each of the four positions.
-     This is not a size hog because the value here is not copied,
-     and will be shared with the specs in the specifier. */
-  Lisp_Object toolbar[4];
-  /* Toolbar size for each of the four positions. */
-  Lisp_Object toolbar_size[4];
-  /* Toolbar visibility status for each of the four positions. */
-  Lisp_Object toolbar_visible_p[4];
-  /* Caption status of toolbar. */
-  Lisp_Object toolbar_buttons_captioned_p;
-  /* The following four don't really need to be cached except
-     that we need to know when they've changed. */
-  Lisp_Object default_toolbar;
-  Lisp_Object default_toolbar_width, default_toolbar_height;
-  Lisp_Object default_toolbar_visible_p;
-#endif /* HAVE_TOOLBARS */
-  Lisp_Object left_margin_width, right_margin_width;
-  Lisp_Object minimum_line_ascent, minimum_line_descent;
-  Lisp_Object use_left_overflow, use_right_overflow;
-#ifdef HAVE_MENUBARS
-  /* Visibility of menubar. */
-  Lisp_Object menubar_visible_p;
-#endif /* HAVE_MENUBARS */
-  Lisp_Object text_cursor_visible_p;
+#define WINDOW_SLOT_DECLARATION
+#define WINDOW_SLOT(slot, compare) Lisp_Object slot
+#include "winslots.h"
 
   /* one-bit flags: */
 
@@ -238,6 +193,9 @@ struct window
   /* new redisplay flag */
   unsigned int windows_changed :1;
   unsigned int shadow_thickness_changed :1;
+  /* Vertical divider flag and validity of it */
+  unsigned int need_vertical_divider_p :1;
+  unsigned int need_vertical_divider_valid_p :1;
 };
 
 #define CURRENT_DISP	0
@@ -292,8 +250,6 @@ DECLARE_LRECORD (window, struct window);
 #define CHECK_WINDOW(x) CHECK_RECORD (x, window)
 #define CONCHECK_WINDOW(x) CONCHECK_RECORD (x, window)
 
-extern Lisp_Object Qwindow_live_p;
-
 #define WINDOW_LIVE_P(x) (!(x)->dead)
 #define CHECK_LIVE_WINDOW(x) do {			\
   CHECK_WINDOW (x);					\
@@ -307,7 +263,7 @@ extern Lisp_Object Qwindow_live_p;
 } while (0)
 
 /* 1 if W is a minibuffer window.  */
-#define MINI_WINDOW_P(W)  (!EQ ((W)->mini_p, Qnil))
+#define MINI_WINDOW_P(W)  (!NILP ((W)->mini_p))
 
 /* 1 if we are dealing with a parentless window (this includes the
    root window on a frame and the minibuffer window; both of these
@@ -318,7 +274,10 @@ extern Lisp_Object Qwindow_live_p;
 #define MARK_WINDOWS_CHANGED(w) do {			\
   (w)->windows_changed = 1;				\
   if (!NILP (w->frame))					\
-    MARK_FRAME_WINDOWS_CHANGED (XFRAME (w->frame));	\
+    {							\
+      struct frame *mwc_frame = XFRAME (w->frame);	\
+      MARK_FRAME_WINDOWS_CHANGED (mwc_frame);		\
+    }							\
   else							\
     windows_changed = 1;				\
 } while (0)
@@ -330,24 +289,32 @@ extern Lisp_Object Qwindow_live_p;
 
 DECLARE_LRECORD (window_configuration, struct window_config);
 
+EXFUN (Fget_buffer_window, 3);
+EXFUN (Fmove_to_window_line, 2);
+EXFUN (Frecenter, 2);
+EXFUN (Freplace_buffer_in_windows, 1);
+EXFUN (Fselect_window, 2);
+EXFUN (Fselected_window, 1);
+EXFUN (Fset_window_buffer, 2);
+EXFUN (Fset_window_hscroll, 2);
+EXFUN (Fset_window_point, 2);
+EXFUN (Fset_window_start, 3);
+EXFUN (Fwindow_buffer, 1);
+EXFUN (Fwindow_highest_p, 1);
+EXFUN (Fwindow_point, 1);
+EXFUN (Fwindow_start, 1);
+
 /* The minibuffer window of the selected frame.
    Note that you cannot test for minibufferness of an arbitrary window
    by comparing against this; but you can test for minibufferness of
    the selected window or of any window that is displayed.  */
 extern Lisp_Object minibuf_window;
 
-/* Non-nil => window to for C-M-v to scroll
-   when the minibuffer is selected.  */
-extern Lisp_Object Vminibuf_scroll_window;
-
 /* Prompt to display in front of the minibuffer contents, or nil */
 extern Lisp_Object Vminibuf_prompt;
 /* Prompt to display in front of the minibuffer prompt, or nil */
 extern Lisp_Object Vminibuf_preprompt;
 
-/* Depth in minibuffer invocations */
-extern int minibuf_level;
-
 Lisp_Object allocate_window (void);
 int window_char_width (struct window *, int include_margins_p);
 int window_char_height (struct window *, int include_gutters_p);
@@ -377,11 +344,8 @@ void window_scroll (Lisp_Object window, Lisp_Object n, int direction,
 int buffer_window_count (struct buffer *b, struct frame *f);
 int buffer_window_mru (struct window *w);
 void check_frame_size (struct frame *frame, int *rows, int *cols);
-void mark_windows_in_use (Lisp_Object window, int mark);
 struct window *decode_window (Lisp_Object window);
-struct window *find_window_by_pixel_pos (unsigned int pix_x,
-					 unsigned int pix_y,
-					 Lisp_Object win);
+struct window *find_window_by_pixel_pos (int pix_x, int pix_y, Lisp_Object win);
 
 /* new functions to handle the window mirror */
 void free_window_mirror (struct window_mirror *mir);
@@ -397,6 +361,9 @@ int map_windows (struct frame *f,
 		 void *closure);
 void some_window_value_changed (Lisp_Object specifier, struct window *w,
 				Lisp_Object oldval);
+int invalidate_vertical_divider_cache_in_window (struct window *w,
+						 void *u_n_u_s_e_d);
+int window_divider_width (struct window *w);
 
 #define WINDOW_FRAME(w) ((w)->frame)
 #define WINDOW_BUFFER(w) ((w)->buffer)
